# NuInfoSys
currently INCOMPLETE -- kekw malding
## Future Goals
* Custom Images (DOTS files)
* Custom Animations (Chaining DOTS files)
* Image + Animation Designer Web App / Software
* A way to know if the current animation list would require too much
memory would be really cool, but would take some investigation
## Codestyle
I have decided to commit to EXTREMELY STRICT typing for this project,
in order to avoid confusion completely and absolutely. You MUST follow
these rules or I won't even look at your code:
* ALL assignments have explicit types
* ALL RE-assignments have explicit types
* ALL functions have return types
* ALL function parameters have types
* Follow any other typing conventions you have heard of

If you follow all these rules and there is still something weird in
your code I will mention it in the review. 

## Running from the CLI
In order to run NuInfoSys from the command line, use the following
command:
```python3.6 -m NuInfoSys.MODULE```
Usually MODULE will be betabrite (i.e. ```python3.6 -m NuInfoSys.betabrite```

## Current Goals, in Rank of Needed Completion
* Memory management

